.. linkml-store

LinkML-Store documentation
==========================

An AI-ready data management and integration platform. LinkML-Store
provides an abstraction layer over multiple different backends
(including DuckDB, MongoDB, and local filesystems), allowing for
common query, index, and storage operations.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   about
   tutorials/index
   how-to/index
   explanation/index
   reference/index
   faq

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
